==> agr-center-api-3.2.0-CLOUD-TEST-20240306.031740-9-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrGetAgrMainListReqBO.java <==
package com.tydic.dyc.agr.service.agr.bo;

import com.tydic.dyc.base.bo.BaseReqBo;
import lombok.Data;

import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrGetAgrMainListReqBO extends BaseReqBo {
	private static final long serialVersionUID =  -8021806858716831368L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议ID集合
	 */
	private List<Long> agrIds;
	/**
	 * 忽略的协议ID集合
	 */
	private List<Long> agrIdsIgnore;
	/**
	 * 当前页
	 */
	private Integer pageNo;
	/**
	 * 每页数量
	 */
	private Integer pageSize;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 铺货单位ID
	 */
	private String managementOrgId;
	/**
	 * 排序
	 */
	private String orderBy;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 创建人单位id
	 */
	private Long createOrgId;
	/**
	 * 创建人单位名称
	 */
	private String createOrgName;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
}

==> agr-center-api-3.2.2-CLOUD-TEST-20240627.080834-3-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrGetAgrMainListReqBO.java <==
package com.tydic.dyc.agr.service.agr.bo;

import com.tydic.dyc.base.bo.BaseReqBo;
import lombok.Data;

import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrGetAgrMainListReqBO extends BaseReqBo {
	private static final long serialVersionUID =  -8021806858716831368L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议ID集合
	 */
	private List<Long> agrIds;
	/**
	 * 忽略的协议ID集合
	 */
	private List<Long> agrIdsIgnore;
	/**
	 * 当前页
	 */
	private Integer pageNo;
	/**
	 * 每页数量
	 */
	private Integer pageSize;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 铺货单位ID
	 */
	private String managementOrgId;
	/**
	 * 排序
	 */
	private String orderBy;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 创建人单位id
	 */
	private Long createOrgId;
	/**
	 * 创建人单位名称
	 */
	private String createOrgName;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 协议创建公司ID
	 */
	private Long createCompanyId;
}
